@@ -77,7 +77,7 @@ IRM <- function(U, Z = NULL, w = NULL, na = NULL,
                 max_iter = 100, stable_limit = 5, minSize = 20, EM_limit = 20,
                 seed = 123, verbose = TRUE) {
   # data format
-  if (class(U)[1] != "exametrika") {
+  if (!inherits(U, "exametrika")) {
     tmp <- dataFormat(data = U, na = na, Z = Z, w = w)
   } else {
     tmp <- U
